@@ -35,10 +35,17 @@ _OPTS = [
                       'hostname, FQDN, or IP address.')),
     cfg.StrOpt('auth_strategy',
                default='keystone',
-               choices=('keystone', 'noauth'),
+               choices=[('noauth', _('no authentication')),
+                        ('keystone', _('use the Identity service for '
+                                       'authentication')),
+                        ('http_basic', _('HTTP basic authentication'))],
                help=_('Authentication method used on the ironic-inspector '
-                      'API. Either "noauth" or "keystone" are currently valid '
+                      'API. "noauth", "keystone" or "http_basic" are valid '
                       'options. "noauth" will disable all authentication.')),
+    cfg.StrOpt('http_basic_auth_user_file',
+               default='/etc/ironic-inspector/htpasswd',
+               help=_('Path to Apache format user authentication file used '
+                      'when auth_strategy=http_basic')),
     cfg.IntOpt('timeout',
                default=3600,
                # We're using timedelta which can overflow if somebody sets this
@@ -48,8 +55,18 @@ _OPTS = [
                       'failed, set to 0 to disable.')),
     cfg.IntOpt('clean_up_period',
                default=60,
+               min=0,
                help=_('Amount of time in seconds, after which repeat clean up '
-                      'of timed out nodes and old nodes status information.')),
+                      'of timed out nodes and old nodes status information. '
+                      'WARNING: If set to a value of 0, then the periodic '
+                      'task is disabled and inspector will not sync with '
+                      'ironic to complete the internal clean-up process. '
+                      'Not advisable if the deployment uses a PXE filter, '
+                      'and will result in the ironic-inspector ceasing '
+                      'periodic cleanup activities.')),
+    cfg.IntOpt('leader_election_interval',
+               default=10,
+               help=_('Interval (in seconds) between leader elections.')),
     cfg.BoolOpt('use_ssl',
                 default=False,
                 help=_('SSL Enabled/Disabled')),
@@ -62,8 +79,7 @@ _OPTS = [
                       'applies when boot is managed by ironic-inspector (i.e. '
                       'manage_boot==True).')),
     cfg.ListOpt('ipmi_address_fields',
-                default=['redfish_address', 'ilo_address', 'drac_host',
-                         'drac_address'],
+                default=['ilo_address', 'drac_host', 'drac_address'],
                 help=_('Ironic driver_info fields that are equivalent '
                        'to ipmi_address.')),
     cfg.StrOpt('rootwrap_config',
@@ -83,7 +99,7 @@ _OPTS = [
                        'endpoint via multicast DNS.')),
     cfg.BoolOpt('standalone', default=True,
                 help=_('Whether to run ironic-inspector as a standalone '
-                       'service. It\'s EXPERIMENTAL to set to False.'))
+                       'service. It\'s EXPERIMENTAL to set to False.')),
 ]
 
 
