@@ -679,13 +679,7 @@ def start_introspection(uuid, **kwargs):
                       node_info=node_info)
             state = istate.States.starting
         else:
-            recorded_state = node_info.state
-            if istate.States.error == recorded_state:
-                # If there was a failure, return to starting state to avoid
-                # letting the cache block new runs from occuring.
-                state = istate.States.starting
-            else:
-                state = recorded_state
+            state = node_info.state
         return add_node(uuid, state, **kwargs)
 
 
