@@ -76,17 +76,11 @@ class RootDiskSelectionHook(base.ProcessingHook):
         root_disk = introspection_data.get('root_disk')
         if root_disk:
             local_gb = root_disk['size'] // units.Gi
-            if not local_gb:
-                LOG.warning('The requested root disk is too small (smaller '
-                            'than 1 GiB) or its size cannot be detected: %s',
-                            root_disk,
-                            node_info=node_info, data=introspection_data)
-            else:
-                if CONF.processing.disk_partitioning_spacing:
-                    local_gb -= 1
-                LOG.info('Root disk %(disk)s, local_gb %(local_gb)s GiB',
-                         {'disk': root_disk, 'local_gb': local_gb},
-                         node_info=node_info, data=introspection_data)
+            if CONF.processing.disk_partitioning_spacing:
+                local_gb -= 1
+            LOG.info('Root disk %(disk)s, local_gb %(local_gb)s GiB',
+                     {'disk': root_disk, 'local_gb': local_gb},
+                     node_info=node_info, data=introspection_data)
         else:
             local_gb = 0
             LOG.info('No root device found, assuming a diskless node',
@@ -300,7 +294,8 @@ class ValidateInterfacesHook(base.ProcessingHook):
                              node_info=node_info, data=introspection_data)
                     node_info.delete_port(port)
 
-        if CONF.processing.overwrite_existing:
+        if (CONF.processing.overwrite_existing
+                and CONF.processing.update_pxe_enabled):
             # Make sure is_pxe_enabled is up-to-date
             ports = node_info.ports()
             for iface in introspection_data['interfaces'].values():
